==> xkcd-2.3.3.zip: xkcd-2.3.3/setup.py <==
# Based from http://pythonhosted.org/setuptools/setuptools.html#automatic-script-creation

from setuptools import setup, find_packages  # Always prefer setuptools over distutils
from codecs import open  # To use a consistent encoding
from os import path

# We shouldn't need pypandoc on remote users's systems just because I dislike rST.
try:
	# Depend on pypandoc for turning markdown readme into RST because
	# PyPI doesn't yet support this.
	import pypandoc

	here = path.abspath(path.dirname(__file__))
	long_description = pypandoc.convert("README.md", "rst")

except ImportError:
	here = path.abspath(path.dirname(__file__))

	# Get the long description from the relevant file
	with open(path.join(here, 'README.md'), encoding='utf-8') as f:
		long_description = f.read()

setup(
	name='xkcd',

	# Versions should comply with PEP440.  For a discussion on single-sourcing
	# the version across setup.py and the project code, see
	# http://packaging.python.org/en/latest/tutorial.html#version
	version='2.3.3',

	description="Library to access xkcd.com",
	long_description=long_description,

	# The project's main homepage.
	url='https://github.com/TC01/python-xkcd',

	# Author details
	author = "Ben Rosser",
	author_email='rosser.bjr@gmail.com',

	# Choose your license
	license='MIT',

	# See https://pypi.python.org/pypi?%3Aaction=list_classifiers
	classifiers=[
		# How mature is this project? Common values are
		#   3 - Alpha
		#   4 - Beta
		#   5 - Production/Stable
		'Development Status :: 5 - Production/Stable',

		# Indicate who your project is intended for
		'Intended Audience :: Developers',
		'Intended Audience :: End Users/Desktop',
		'Topic :: Software Development :: Libraries',
		'Topic :: Internet :: WWW/HTTP',
		'Topic :: Internet :: WWW/HTTP :: Dynamic Content',

		# Pick your license as you wish (should match "license" above)
		'License :: OSI Approved :: MIT License',

		# Specify the Python versions you support here. In particular, ensure
		# that you indicate whether you support Python 2, Python 3 or both.
		'Programming Language :: Python :: 2',
		'Programming Language :: Python :: 2.7',
		'Programming Language :: Python :: 3',
		'Programming Language :: Python :: 3.3',
		'Programming Language :: Python :: 3.4',
		'Programming Language :: Python :: 3.5',
	],

	# What does your project relate to?
	keywords='xkcd webcomic',

	# You can just specify the packages manually here if your project is
	# simple. Or you can use find_packages().
#	packages=find_packages(exclude=['contrib', 'docs', 'tests*']),
	py_modules=['xkcd'],

	# List run-time dependencies here.  These will be installed by pip when your
	# project is installed. For an analysis of "install_requires" vs pip's
	# requirements files see:
	# https://packaging.python.org/en/latest/technical.html#install-requires-vs-requirements-files
	#install_requires=['peppercorn'],

	# If there are data files included in your packages that need to be
	# installed, specify them here.  If using Python 2.6 or less, then these
	# have to be included in MANIFEST.in as well.
	#package_data={
	#	'sample': ['package_data.dat'],
	#},

	# Although 'package_data' is the preferred approach, in some case you may
	# need to place data files outside of your packages.
	# see http://docs.python.org/3.4/distutils/setupscript.html#installing-additional-files
	# In this case, 'data_file' will be installed into '<sys.prefix>/my_data'
	#data_files=[('my_data', ['data/data_file'])],

	# To provide executable scripts, use entry points in preference to the
	# "scripts" keyword. Entry points provide cross-platform support and allow
	# pip to create the appropriate form of executable for the target platform.
#	entry_points={
#		'console_scripts': [
#			'calcpkg=calcrepo.calcpkg:main',
#		],
#	},
	)

==> xkcd-2.4.0.zip: xkcd-2.4.0/setup.py <==
# Based from http://pythonhosted.org/setuptools/setuptools.html#automatic-script-creation

from setuptools import setup, find_packages  # Always prefer setuptools over distutils
from codecs import open  # To use a consistent encoding
from os import path

# We shouldn't need pypandoc on remote users's systems just because I dislike rST.
try:
	# Depend on pypandoc for turning markdown readme into RST because
	# PyPI doesn't yet support this.
	import pypandoc

	here = path.abspath(path.dirname(__file__))
	long_description = pypandoc.convert("README.md", "rst")

except ImportError:
	here = path.abspath(path.dirname(__file__))

	# Get the long description from the relevant file
	with open(path.join(here, 'README.md'), encoding='utf-8') as f:
		long_description = f.read()

setup(
	name='xkcd',

	# Versions should comply with PEP440.  For a discussion on single-sourcing
	# the version across setup.py and the project code, see
	# http://packaging.python.org/en/latest/tutorial.html#version
	version='2.4.0',

	description="Library to access xkcd.com",
	long_description=long_description,

	# The project's main homepage.
	url='https://github.com/TC01/python-xkcd',

	# Author details
	author = "Ben Rosser",
	author_email='rosser.bjr@gmail.com',

	# Choose your license
	license='MIT',

	# See https://pypi.python.org/pypi?%3Aaction=list_classifiers
	classifiers=[
		# How mature is this project? Common values are
		#   3 - Alpha
		#   4 - Beta
		#   5 - Production/Stable
		'Development Status :: 5 - Production/Stable',

		# Indicate who your project is intended for
		'Intended Audience :: Developers',
		'Intended Audience :: End Users/Desktop',
		'Topic :: Software Development :: Libraries',
		'Topic :: Internet :: WWW/HTTP',
		'Topic :: Internet :: WWW/HTTP :: Dynamic Content',

		# Pick your license as you wish (should match "license" above)
		'License :: OSI Approved :: MIT License',

		# Specify the Python versions you support here. In particular, ensure
		# that you indicate whether you support Python 2, Python 3 or both.
		'Programming Language :: Python :: 2',
		'Programming Language :: Python :: 2.7',
		'Programming Language :: Python :: 3',
		'Programming Language :: Python :: 3.3',
		'Programming Language :: Python :: 3.4',
		'Programming Language :: Python :: 3.5',
	],

	# What does your project relate to?
	keywords='xkcd webcomic whatif',

	# You can just specify the packages manually here if your project is
	# simple. Or you can use find_packages().
#	packages=find_packages(exclude=['contrib', 'docs', 'tests*']),
	py_modules=['xkcd'],

	# List run-time dependencies here.  These will be installed by pip when your
	# project is installed. For an analysis of "install_requires" vs pip's
	# requirements files see:
	# https://packaging.python.org/en/latest/technical.html#install-requires-vs-requirements-files
	#install_requires=['peppercorn'],

	# If there are data files included in your packages that need to be
	# installed, specify them here.  If using Python 2.6 or less, then these
	# have to be included in MANIFEST.in as well.
	#package_data={
	#	'sample': ['package_data.dat'],
	#},

	# Although 'package_data' is the preferred approach, in some case you may
	# need to place data files outside of your packages.
	# see http://docs.python.org/3.4/distutils/setupscript.html#installing-additional-files
	# In this case, 'data_file' will be installed into '<sys.prefix>/my_data'
	#data_files=[('my_data', ['data/data_file'])],

	# To provide executable scripts, use entry points in preference to the
	# "scripts" keyword. Entry points provide cross-platform support and allow
	# pip to create the appropriate form of executable for the target platform.
#	entry_points={
#		'console_scripts': [
#			'calcpkg=calcrepo.calcpkg:main',
#		],
#	},

	# Test suites.
	test_suite = 'tests',

	)
